@@ -3,8 +3,8 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION == "2.2.0" or
-    raise "ruby lib version (2.2.0) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("2.2.2"[/^[0-9]+[.][0-9]+[.]/]) or
+    raise "ruby lib version (2.2.2) doesn't match executable version (#{RUBY_VERSION})"
 
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.2/x86_64-openbsd")
   DESTDIR = '' unless defined? DESTDIR
@@ -13,8 +13,8 @@ module RbConfig
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "2"
   CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "0"
-  CONFIG["INSTALL"] = '/usr/obj/ruby-2.2.0/bin/install -c '
+  CONFIG["PATCHLEVEL"] = "95"
+  CONFIG["INSTALL"] = '/usr/obj/ruby-2.2.2/bin/install -c '
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)22"
@@ -78,7 +78,7 @@ module RbConfig
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.0.0"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.1.0"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
@@ -96,7 +96,7 @@ module RbConfig
   CONFIG["INSTALLDOC"] = "all"
   CONFIG["CAPITARGET"] = "nodoc"
   CONFIG["RDOCTARGET"] = "rdoc"
-  CONFIG["DTRACE_GLOMMED_OBJ"] = ""
+  CONFIG["DTRACE_REBUILD"] = ""
   CONFIG["DTRACE_OBJ"] = ""
   CONFIG["DTRACE_EXT"] = "dmyh"
   CONFIG["EXECUTABLE_EXTS"] = ""
@@ -145,9 +145,9 @@ module RbConfig
   CONFIG["DTRACE"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/usr/obj/ruby-2.2.0/bin/install -c  -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ruby-2.2.0/bin/install -c  -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ruby-2.2.0/bin/install -c -s  -m 755"
+  CONFIG["INSTALL_DATA"] = "/usr/obj/ruby-2.2.2/bin/install -c  -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ruby-2.2.2/bin/install -c  -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ruby-2.2.2/bin/install -c -s  -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -181,22 +181,22 @@ module RbConfig
   CONFIG["NACL_SDK_VARIANT"] = ""
   CONFIG["NACL_SDK_ROOT"] = ""
   CONFIG["NACL_TOOLCHAIN"] = ""
-  CONFIG["target_os"] = "openbsd5.7"
+  CONFIG["target_os"] = "openbsd5.8"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "x86_64"
-  CONFIG["target"] = "x86_64-unknown-openbsd5.7"
-  CONFIG["host_os"] = "openbsd5.7"
+  CONFIG["target"] = "x86_64-unknown-openbsd5.8"
+  CONFIG["host_os"] = "openbsd5.8"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "x86_64"
-  CONFIG["host"] = "x86_64-unknown-openbsd5.7"
+  CONFIG["host"] = "x86_64-unknown-openbsd5.8"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd5.7"
+  CONFIG["build_os"] = "openbsd5.8"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "x86_64"
-  CONFIG["build"] = "x86_64-unknown-openbsd5.7"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.2.0"
+  CONFIG["build"] = "x86_64-unknown-openbsd5.8"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.2.2"
   CONFIG["HAVE_BASERUBY"] = "no"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
